@@ -1,8 +1,8 @@
 #!/bin/bash
 # ----------------------------------------------------------------------------------------------------------
-#  Copyright 2003-2011 Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2008 Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2011/mm/dd, v3.002.003, generateCollectorDaemonSchedulingReports.sh
+# 2008/02/13, v3.000.016, generateCollectorDaemonSchedulingReports.sh
 # ----------------------------------------------------------------------------------------------------------
 
 if [ -f ~/.profile ]; then
@@ -13,7 +13,7 @@ if [ -f ~/.bash_profile ]; then
   source ~/.bash_profile
 fi
 
-AMPATH=/opt/asnmtap
+AMPATH=/opt/asnmtap-3.000.xxx
 
 if [ "$ASNMTAP_PATH" ]; then
   AMPATH=$ASNMTAP_PATH
