@@ -1,8 +1,8 @@
-#!/usr/local/bin/perl
+#!/bin/env perl
 # ---------------------------------------------------------------------------------------------------------
-#  Copyright 2003-2007 Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2008 Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2007/10/21, v3.000.015, htmlToPdf.pl for ASNMTAP::Asnmtap::Applications::CGI
+# 2008/02/13, v3.000.016, htmlToPdf.pl for ASNMTAP::Asnmtap::Applications::CGI
 # ---------------------------------------------------------------------------------------------------------
 # Compatible with HTMLDOC v1.8.27 from http://www.htmldoc.org/ or http://www.easysw.com/htmldoc
 # ----------------------------------------------------------------------------------------------------------
@@ -21,7 +21,7 @@ use CGI;
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Asnmtap::Applications::CGI v3.000.015;
+use ASNMTAP::Asnmtap::Applications::CGI v3.000.016;
 use ASNMTAP::Asnmtap::Applications::CGI qw(:APPLICATIONS :CGI :MEMBER &call_system);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -32,7 +32,7 @@ use vars qw($PROGNAME);
 
 $PROGNAME       = "htmlToPdf.pl";
 my $prgtext     = "HTML to PDF";
-my $version     = do { my @r = (q$Revision: 3.000.015$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
+my $version     = do { my @r = (q$Revision: 3.000.016$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -85,7 +85,7 @@ if ((!defined $scriptname) or (!defined $sessionID)) {
 
   my $refresh = '';
 
-  if ($HTMLtoPDFprg eq "htmldoc") {
+  if ($HTMLtoPDFprg eq 'htmldoc') {
     my $extension = ($HTMLtoPDFhow eq 'cgi') ? 'cgi' : 'sh';
     $refresh = "1; url=/cgi-bin/$HTMLtoPDFprg.$extension$scriptname?$urlAccessParameters";
   }
