@@ -1,8 +1,8 @@
-#!/usr/local/bin/perl
+#!/bin/env perl
 # ---------------------------------------------------------------------------------------------------------
-#  Copyright 2003-2007 Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2008 Alex Peeters [alex.peeters@citap.be]
 # ---------------------------------------------------------------------------------------------------------
-# 2007/10/21, v3.000.015, session.pl for ASNMTAP::Asnmtap::Applications::CGI
+# 2008/02/13, v3.000.016, session.pl for ASNMTAP::Asnmtap::Applications::CGI
 # ---------------------------------------------------------------------------------------------------------
 
 use strict;
@@ -15,7 +15,7 @@ BEGIN { if ( $ENV{ASNMTAP_PERL5LIB} ) { eval 'use lib ( "$ENV{ASNMTAP_PERL5LIB}"
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
-use ASNMTAP::Asnmtap::Applications::CGI v3.000.015;
+use ASNMTAP::Asnmtap::Applications::CGI v3.000.016;
 use ASNMTAP::Asnmtap::Applications::CGI qw(:APPLICATIONS :CGI :MODERATOR);
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -26,7 +26,7 @@ use vars qw($PROGNAME);
 
 $PROGNAME       = "sessions.pl";
 my $prgtext     = "Blocked Sessions";
-my $version     = do { my @r = (q$Revision: 3.000.015$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
+my $version     = do { my @r = (q$Revision: 3.000.016$ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r }; # must be all on one line or MakeMaker will get confused.
 
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
 
@@ -81,7 +81,7 @@ if ( defined $sessionID and ! defined $errorUserAccessControl ) {
         $htmlTitle = "Session '$cgisessFilename' deleted";
       }
     } else {
-      $htmlTitle = "Session '$cgisessFilename' not deleted, don't exists";
+      $htmlTitle = "Session '$cgisessFilename' not deleted, doesn't exist";
     }
   } elsif ($action eq 'detailsView') {
     $htmlTitle    = "Details for session '$CsessionID'";
@@ -254,7 +254,7 @@ if ( defined $sessionID and ! defined $errorUserAccessControl ) {
       unlink ($CGISESSPATH.'/'.$cgisessFilename);	
       $htmlTitle = "Session '$cgisessFilename' unblocked";
     } else {
-      $htmlTitle = "Session '$cgisessFilename' not unblocked, don't exists";
+      $htmlTitle = "Session '$cgisessFilename' not unblocked, doesn't exist";
     }
   }
 
