@@ -1,8 +1,8 @@
 #!/bin/bash
 # ----------------------------------------------------------------------------------------------------------
-#  Copyright 2003-2011 Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2008 Alex Peeters [alex.peeters@citap.be]
 # ----------------------------------------------------------------------------------------------------------
-# 2011/mm/dd, v3.002.003, perfparse_crontab_failed.sh
+# 2008/02/13, v3.000.016, perfparse_crontab_failed.sh
 # ----------------------------------------------------------------------------------------------------------
 
 if [ -f ~/.profile ]; then
@@ -13,38 +13,32 @@ if [ -f ~/.bash_profile ]; then
   source ~/.bash_profile
 fi
 
-AMPATH=/opt/asnmtap-3.001.xxx
+AMPATH=/opt/asnmtap-3.000.xxx
 
 if [ "$ASNMTAP_PATH" ]; then
   AMPATH=$ASNMTAP_PATH
 fi
 
-PERFPARSEPATH=/opt/asnmtap/perfparse
-
 for file in $( find $AMPATH/log/ -name 'perfdata-asnmtap.log-*-failed' ) 
 do
   echo "Filename failed: '$file'";
-# cat $file | $PERFPARSEPATH/bin/perfparse-log2mysql
-# rv="$?"
+  cat $file | $AMPATH/perfparse/bin/perfparse-log2mysql
+  rv="$?"
 
-# if [ ! "$rv" = "0" ]; then
+  if [ ! "$rv" = "0" ]; then
     exec 3<&0
     exec 0<$file
 
     while read line
     do
-      echo "$line" | $PERFPARSEPATH/bin/perfparse-log2mysql
-        rv="$?"
-
-        if [ ! "$rv" = "0" ]; then
-          echo "$line" >> "$file-manual-action-needed"
-        fi
+      echo $line | $AMPATH/perfparse/bin/perfparse-log2mysql
     done
 
     exec 0<&3
-# fi
+  fi
 
   rm $file
 done
 
 exit 0
+
