@@ -1,12 +1,12 @@
-#!/usr/bin/env perl
+#!/bin/env perl
 # ------------------------------------------------------------------------------
-#  Copyright 2003-2011 Alex Peeters [alex.peeters@citap.be]
+#  Copyright 2003-2008 Alex Peeters [alex.peeters@citap.be]
 # ------------------------------------------------------------------------------
-# rsync-wrapper-distributed.sh for asnmtap, v2.002.xxx - wrapper script for rsync
-#   execution via ssh key for use with rsync-mirror-distributed.sh & rsync-mirror.conf
+# rsync-wrapper for asnmtap, v2.002.xxx - wrapper script for rsync
+#   execution via ssh key for use with rsync-mirror & rsync-mirror.conf
 #
-#   rsync-wrapper need to be installed onto the master server into /opt/asnmtap/applications/master and
-#   rsync-mirror.sh & rsync-mirror.conf onto the slave server into /opt/asnmtap/applications/slave
+#   rsync-wrapper need to be installed onto the master server into /opt/asnmtap-3.000.xxx/applications/master and
+#   rsync-mirror.sh & rsync-mirror.conf onto the slave server into /opt/asnmtap-3.000.xxx/applications/slave
 #
 #   Accepted rsync calls are as follows:
 #     rsync --server --sender @options . $chrootDir/../../otherdir would succeed
@@ -23,10 +23,10 @@
 use strict;
 
 # Chroot Dir
-my $chrootDir = '/opt/asnmtap/results/';
+my $chrootDir = '/opt/asnmtap-3.000.xxx/results/';
 
 # Where to log successes and failures to set to /dev/null to turn off logging.
-my $filename = '/opt/asnmtap/asnmtap/log/rsync-wrapper-distributed-template.log';
+my $filename = '/opt/asnmtap-3.000.xxx/log/asnmtap/rsync-wrapper-distributed-template.log';
 
 # What you want sent if access is denied.
 my $denyString = 'Access Denied! Sorry';
@@ -44,12 +44,10 @@ my $captureOutput = 1;
 # DON'T TOUCH BELOW HERE UNLESS YOU KNOW WHAT YOU ARE DOING!
 # ------------------------------------------------------------------------------
 
-my @options = ('-logDtpr',       '-nlogDtpr',       '-vlogDtpr',       '-vnlogDtpr',
-               '-logDtprz',      '-nlogDtprz',      '-vlogDtprz',      '-vnlogDtprz',
-               '-logDtprc',      '-nlogDtprc',      '-vlogDtprc',      '-vnlogDtprc',
-               '-logDtprcz',     '-nlogDtprcz',     '-vlogDtprcz',     '-vnlogDtprcz',
-               '-logDtprcze.s',  '-nlogDtprcze.s',  '-vlogDtprcze.s',  '-vnlogDtprcze.s',
-               '-logDtprcze.is', '-nlogDtprcze.is', '-vlogDtprcze.is', '-vnlogDtprcze.is');
+my @options = ('-logDtpr',   '-nlogDtpr',   '-vlogDtpr',   '-vnlogDtpr',
+               '-logDtprz',  '-nlogDtprz',  '-vlogDtprz',  '-vnlogDtprz',
+               '-logDtprc',  '-nlogDtprc',  '-vlogDtprc',  '-vnlogDtprc',
+               '-logDtprcz', '-nlogDtprcz', '-vlogDtprcz', '-vnlogDtprcz');
 
 my $TRUE  = (0 == 0);
 my $FALSE = (0 == 1);
@@ -95,7 +93,7 @@ print SSHOUT ("ARG4 = $rsync_argv[4]\n") if ($debug);
 print SSHOUT ("ARG5 = $rsync_argv[5]\n") if ($debug && $rsync_argv[2] eq '--sender');
 
 # ARG[0] Complain if the command is not 'rsync'.
-unless ($rsync_argv[0] =~ 'rsync') {
+unless ($rsync_argv[0] eq 'rsync') {
   print SSHOUT ("ssh authorized_key account restricted: only rsync allowed\n");
   $ok = $FALSE;
 }
